@@ -1,5 +1,5 @@
 from PyQt4.QtGui import QMainWindow, QGraphicsView
-from PyQt4.QtCore import pyqtSignature, Qt, QMimeData, SIGNAL, QPoint
+from PyQt4.QtCore import pyqtSignature, Qt, SIGNAL, QPoint
 
 
 
@@ -41,8 +41,7 @@ class styloKeys(QGraphicsView):
                self.emit(SIGNAL("stylo changed"),self.buttonid)        
                self.keyrelease=0
                #print "pressed", self.buttonid
-            elif self.buttonid!=self.lastbutton:
-               if self.buttonid<=12:self.emit(SIGNAL("stylo changed"), self.buttonid)
+            elif self.buttonid!=self.lastbutton:self.emit(SIGNAL("stylo changed"), self.buttonid)
                #print "moved", self.buttonid
             
             self.lastbutton=self.buttonid
